//+------------------------------------------------------------------+
//| BasketEA.mq4
//| By Xaphod
//+------------------------------------------------------------------+
#property copyright "Copyright ?2011, Basket Case"
#property link      "www.forexfactory.com/xaphod"

// Definitions
#define MAX_TICKETS 6

// Input parameters
extern double Lots = 0.1;
extern double Slippage = 2.0;
extern double TakeProfit = 25;
extern double StopLoss = 15;
extern int    MagicNr=100;

// Global variables
int giTicket[MAX_TICKETS];

//-----------------------------------------------------------------------------
// function: init()
// Description: Custom indicator initialization function.
//-----------------------------------------------------------------------------
int init() {
  // Reset all ticket to free
  for (int i=0; i<MAX_TICKETS;i++)
    giTicket[i]=-1;
}

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start() { 
  double ArrowUp, ArrowDown;
  static datetime tCurTime;
  int iFreeTicket=-1;
  int i;
  
  // Get Supersignal state
  ArrowUp = iCustom(NULL,0,"supersignals",1,1);
  ArrowDown = iCustom(NULL,0,"supersignals",0,1);
  
  // Open orders on new bar only
  if (tCurTime != Time[0]) {
    tCurTime=Time[0];
    
    // Get the first free ticket
    iFreeTicket=GetFreeTicket();
    
    // Open Buy order if previous bar has arrow up signal
    if  (ArrowUp!=EMPTY_VALUE && iFreeTicket>-1) {
      giTicket[iFreeTicket]=OrderSend(Symbol(),OP_BUY,Lots, Ask, Slippage, 0, 0, 
                                       "Supersignal", MagicNr+i, NULL, LimeGreen);    
    }
    // Open Sell order if previous bar has arrow up signal
    if  (ArrowDown!=EMPTY_VALUE && iFreeTicket>-1) {
      giTicket[iFreeTicket]=OrderSend(Symbol(),OP_SELL,Lots, Bid, Slippage, 0, 0,
                                      "Supersignal", MagicNr+i, NULL, LimeGreen);    
    }
  }
  
  // Check SL and TP for each ticket
  for ( i=0; i<MAX_TICKETS;i++) {    
    if (OrderSelect( giTicket[i], SELECT_BY_TICKET)==True) {
      // Check SL and TP for BUY ticket
      if (OrderType()==OP_BUY) {
        // Close position if SL is Hit
        if (ToPips(Bid,OrderOpenPrice())<=-StopLoss)
          if ( OrderClose(giTicket[i],Lots,Bid,Slippage)==True)
            giTicket[i]=-1; 
        // Close position if TP is Hit     
        if (ToPips(Bid,OrderOpenPrice())>=TakeProfit)
          if ( OrderClose(giTicket[i],Lots,Bid,Slippage)==True)
            giTicket[i]=-1;       
        //Print("Buy. Current Pips=",dPips(OrderOpenPrice(),Bid));  
      }
      // Check SL and TP for SELL ticket
      if (OrderType()==OP_SELL ) {
        // Close position if SL is Hit
        if (ToPips(OrderOpenPrice(),Ask)>=StopLoss)
          if ( OrderClose(giTicket[i],Lots,Ask,Slippage)==True)
            giTicket[i]=-1;   
        // Close position if TP is Hit
        if (ToPips(OrderOpenPrice(),Ask)<=-TakeProfit)
          if ( OrderClose(giTicket[i],Lots,Ask,Slippage)==True)
            giTicket[i]=-1;   
        //Print("Sell. Current Pips=",dPips(OrderOpenPrice(),Bid));  
      }
    }
  }
  
  return(0);
}

//---------------------------------------------------------------
// function: GetFreeTicket()
// Description: Return the index of the first free ticket, or -1
//---------------------------------------------------------------
int GetFreeTicket() {
  for (int i=0; i<MAX_TICKETS;i++)
    if (giTicket[i]==-1)
      return(i);
  return(-1);      
} 

//----------------------------------------------------------------
// function: ToPips()
// Description: Convert a price difference to pips.
//----------------------------------------------------------------
double ToPips(double dPrice1,double dPrice2,bool bAbs=false) {
  double dPipValue=(dPrice1-dPrice2)/Point; 
  if (bAbs) return( MathAbs(dPipValue));
  else return(dPipValue);
} 



